@@ -5,7 +5,7 @@ with open("easypymongodb/README.md", "r") as fhandle:
 
 setuptools.setup(
   name="easypymongodb", # Put your username here!
-  version="0.0.2", # The version of your package!
+  version="0.0.6", # The version of your package!
   author="Zeliktric", # Your name here!
   author_email="zeliktric@gmail.com", # Your e-mail here!
   description="A package that simplifies the use of the pymongo library.", # A short description here!
@@ -20,4 +20,8 @@ setuptools.setup(
   ], # Enter meta data into the classifiers list!
   python_requires=">=3.6", # The version requirement for Python to run your package!
   keywords = ["DB", "database", "mongo", "pymongo", "easypymongodb", "python", "db"],
+  install_requires=[            
+    "pymongo",
+    "dnspython"
+  ],
 )
